@@ -27,6 +27,7 @@ class SerializeVocabLikeToJson:
         vocabulary = self.context
         title = safe_unicode(self.request.form.get("title", ""))
         token = self.request.form.get("token", "")
+        b_size = self.request.form.get("b_size", "")
 
         terms = []
         for term in vocabulary:
@@ -45,13 +46,26 @@ class SerializeVocabLikeToJson:
                 terms.append(term)
             else:
                 term_title = safe_unicode(getattr(term, "title", None) or "")
-                if title.lower() not in term_title.lower():
+                if (
+                    title.lower()
+                    not in translate(term_title, context=self.request).lower()
+                ):
                     continue
                 terms.append(term)
 
+        serialized_terms = []
+
+        # Do not batch parameter is set
+        if b_size == "-1":
+            for term in terms:
+                serializer = getMultiAdapter(
+                    (term, self.request), interface=ISerializeToJson
+                )
+                serialized_terms.append(serializer())
+            return {"@id": vocabulary_id, "items": serialized_terms}
+
         batch = HypermediaBatch(self.request, terms)
 
-        serialized_terms = []
         for term in batch:
             serializer = getMultiAdapter(
                 (term, self.request), interface=ISerializeToJson
