@@ -5,7 +5,7 @@ class DatabaseGet(Service):
     def reply(self):
         db = self.context._p_jar.db()
         return {
-            "@id": "{}/@database".format(self.context.absolute_url()),
+            "@id": f"{self.context.absolute_url()}/@database",
             "cache_length": db.cacheSize(),
             "cache_length_bytes": db.getCacheSizeBytes(),
             "cache_detail_length": db.cacheDetailSize(),
