@@ -10,7 +10,7 @@ class UsersDelete(Service):
     """Deletes a user."""
 
     def __init__(self, context, request):
-        super(UsersDelete, self).__init__(context, request)
+        super().__init__(context, request)
         self.params = []
 
     def publishTraverse(self, request, name):
