@@ -1,5 +1,5 @@
 from Products.CMFCore.utils import getToolByName
-from six.moves.urllib.parse import urlparse
+from urllib.parse import urlparse
 
 import quopri
 
