@@ -57,7 +57,7 @@ class TestCommentsSerializers(TestCase):
         )
 
         output = serializer()
-        self.assertEqual(set(output), set(["@id", "items_total", "items"]))
+        self.assertEqual(set(output), {"@id", "items_total", "items"})
 
     def test_conversation_batched(self):
         self.request.form["b_size"] = 1
@@ -91,7 +91,7 @@ class TestCommentsSerializers(TestCase):
         ]
         self.assertEqual(set(output), set(expected))
 
-        self.assertEqual(set(output["text"]), set(["data", "mime-type"]))
+        self.assertEqual(set(output["text"]), {"data", "mime-type"})
 
     def test_comment_with_author_image(self):
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
@@ -109,7 +109,7 @@ class TestCommentsSerializers(TestCase):
 
         serializer = getMultiAdapter((self.comment, self.request), ISerializeToJson)
         self.assertEqual(
-            "{}/portal_memberdata/portraits/test_user_1_".format(self.portal_url),
+            f"{self.portal_url}/portal_memberdata/portraits/test_user_1_",
             serializer().get("author_image"),
         )
 
