@@ -86,7 +86,7 @@ class TestFolderCreate(unittest.TestCase):
         roles = [x for x in response.json()["entries"] if x["id"] == "admin"]
         roles = roles[0]["roles"]
 
-        new_roles = dict([(key, not val) for key, val in roles.items()])
+        new_roles = {key: not val for key, val in roles.items()}
         payload = {"entries": [{"id": "admin", "roles": new_roles}]}
 
         response = requests.post(
@@ -119,10 +119,10 @@ class TestFolderCreate(unittest.TestCase):
         available_roles = response.json()["available_roles"]
         self.assertEqual(
             [
-                {u"id": u"Contributor", u"title": u"Kann hinzuf\xfcgen"},
-                {u"id": u"Editor", u"title": u"Kann bearbeiten"},
-                {u"id": u"Reader", u"title": u"Kann ansehen"},
-                {u"id": u"Reviewer", u"title": u"Kann ver\xf6ffentlichen"},
+                {"id": "Contributor", "title": "Kann hinzuf\xfcgen"},
+                {"id": "Editor", "title": "Kann bearbeiten"},
+                {"id": "Reader", "title": "Kann ansehen"},
+                {"id": "Reviewer", "title": "Kann ver\xf6ffentlichen"},
             ],
             available_roles,
         )
@@ -148,28 +148,28 @@ class TestFolderCreate(unittest.TestCase):
         self.assertEqual(
             response.json(),
             {
-                u"available_roles": [
-                    {u"id": u"Contributor", u"title": u"Can add"},
-                    {u"id": u"Editor", u"title": u"Can edit"},
-                    {u"id": u"Reader", u"title": u"Can view"},
-                    {u"id": u"Reviewer", u"title": u"Can review"},
+                "available_roles": [
+                    {"id": "Contributor", "title": "Can add"},
+                    {"id": "Editor", "title": "Can edit"},
+                    {"id": "Reader", "title": "Can view"},
+                    {"id": "Reviewer", "title": "Can review"},
                 ],
-                u"entries": [
+                "entries": [
                     {
-                        u"disabled": False,
-                        u"id": u"AuthenticatedUsers",
-                        u"login": None,
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": False,
-                            u"Reviewer": False,
+                        "disabled": False,
+                        "id": "AuthenticatedUsers",
+                        "login": None,
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": False,
+                            "Reviewer": False,
                         },
-                        u"title": u"Logged-in users",
-                        u"type": u"group",
+                        "title": "Logged-in users",
+                        "type": "group",
                     }
                 ],
-                u"inherit": True,
+                "inherit": True,
             },
         )
 
@@ -189,40 +189,40 @@ class TestFolderCreate(unittest.TestCase):
         self.assertEqual(
             response.json(),
             {
-                u"available_roles": [
-                    {u"id": u"Contributor", u"title": u"Can add"},
-                    {u"id": u"Editor", u"title": u"Can edit"},
-                    {u"id": u"Reader", u"title": u"Can view"},
-                    {u"id": u"Reviewer", u"title": u"Can review"},
+                "available_roles": [
+                    {"id": "Contributor", "title": "Can add"},
+                    {"id": "Editor", "title": "Can edit"},
+                    {"id": "Reader", "title": "Can view"},
+                    {"id": "Reviewer", "title": "Can review"},
                 ],
-                u"entries": [
+                "entries": [
                     {
-                        u"disabled": False,
-                        u"id": u"AuthenticatedUsers",
-                        u"login": None,
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": False,
-                            u"Reviewer": False,
+                        "disabled": False,
+                        "id": "AuthenticatedUsers",
+                        "login": None,
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": False,
+                            "Reviewer": False,
                         },
-                        u"title": u"Logged-in users",
-                        u"type": u"group",
+                        "title": "Logged-in users",
+                        "type": "group",
                     },
                     {
-                        u"disabled": False,
-                        u"id": u"test_user_1_",
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": False,
-                            u"Reviewer": True,
+                        "disabled": False,
+                        "id": "test_user_1_",
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": False,
+                            "Reviewer": True,
                         },
-                        u"title": u"test-user",
-                        u"type": u"user",
+                        "title": "test-user",
+                        "type": "user",
                     },
                 ],
-                u"inherit": True,
+                "inherit": True,
             },
         )
 
@@ -241,14 +241,14 @@ class TestFolderCreate(unittest.TestCase):
             json={
                 "entries": [
                     {
-                        u"id": TEST_USER_ID,
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": True,
-                            u"Reviewer": True,
+                        "id": TEST_USER_ID,
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": True,
+                            "Reviewer": True,
                         },
-                        u"type": u"user",
+                        "type": "user",
                     }
                 ]
             },
@@ -261,7 +261,7 @@ class TestFolderCreate(unittest.TestCase):
             sorted_roles(pas.getLocalRolesForDisplay(self.portal.folder1)),
             [
                 ["admin", ["Owner"], "user", "admin"],
-                ["test-user", [u"Reader", u"Reviewer"], "user", u"test_user_1_"],
+                ["test-user", ["Reader", "Reviewer"], "user", "test_user_1_"],
             ],
         )
 
@@ -289,16 +289,16 @@ class TestFolderCreate(unittest.TestCase):
             json={
                 "entries": [
                     {
-                        u"id": TEST_USER_ID,
-                        u"roles": {
-                            u"Contributor": True,
-                            u"Editor": True,
-                            u"Reader": True,
-                            u"Publisher": True,
-                            u"Reviewer": True,
-                            u"Manager": True,
+                        "id": TEST_USER_ID,
+                        "roles": {
+                            "Contributor": True,
+                            "Editor": True,
+                            "Reader": True,
+                            "Publisher": True,
+                            "Reviewer": True,
+                            "Manager": True,
                         },
-                        u"type": u"user",
+                        "type": "user",
                     }
                 ]
             },
@@ -311,10 +311,10 @@ class TestFolderCreate(unittest.TestCase):
 
         # New roles should not contain any new roles that the user didn't
         # have permission to delegate.
-        self.assertNotIn(u"Manager", new_roles)
-        self.assertNotIn(u"Publisher", new_roles)
-        self.assertNotIn(u"Reviewer", new_roles)
-        self.assertNotIn(u"Contributor", new_roles)
+        self.assertNotIn("Manager", new_roles)
+        self.assertNotIn("Publisher", new_roles)
+        self.assertNotIn("Reviewer", new_roles)
+        self.assertNotIn("Contributor", new_roles)
 
         # 'Reader' gets added because the permission to delegate it is
         # assigned to 'Editor' by default (see p.a.workflow.permissions)
@@ -373,16 +373,16 @@ class TestFolderCreate(unittest.TestCase):
             json={
                 "entries": [
                     {
-                        u"id": "peter",
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": True,
-                            u"Reader": True,
-                            u"Publisher": False,
-                            u"Reviewer": True,
-                            u"Manager": False,
+                        "id": "peter",
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": True,
+                            "Reader": True,
+                            "Publisher": False,
+                            "Reviewer": True,
+                            "Manager": False,
                         },
-                        u"type": u"user",
+                        "type": "user",
                     }
                 ]
             },
@@ -393,7 +393,7 @@ class TestFolderCreate(unittest.TestCase):
         self.assertEqual(response.status_code, 204)
         new_roles = api.user.get_roles(username="peter", obj=self.portal.folder1)
 
-        self.assertIn(u"Reviewer", new_roles)
+        self.assertIn("Reviewer", new_roles)
         self.assertEqual(
             sorted(["Member", "Authenticated", "Editor", "Reader", "Reviewer"]),
             sorted(new_roles),
@@ -421,14 +421,14 @@ class TestFolderCreate(unittest.TestCase):
             json={
                 "entries": [
                     {
-                        u"id": TEST_USER_ID,
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": False,
-                            u"Reviewer": True,
+                        "id": TEST_USER_ID,
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": False,
+                            "Reviewer": True,
                         },
-                        u"type": u"user",
+                        "type": "user",
                     }
                 ]
             },
@@ -441,7 +441,7 @@ class TestFolderCreate(unittest.TestCase):
             pas.getLocalRolesForDisplay(self.portal.folder1),
             (
                 ("admin", ("Owner",), "user", "admin"),
-                ("test-user", (u"Reviewer",), "user", u"test_user_1_"),
+                ("test-user", ("Reviewer",), "user", "test_user_1_"),
             ),
         )
 
@@ -460,14 +460,14 @@ class TestFolderCreate(unittest.TestCase):
             json={
                 "entries": [
                     {
-                        u"id": TEST_USER_ID,
-                        u"roles": {
-                            u"Contributor": False,
-                            u"Editor": False,
-                            u"Reader": True,
-                            u"Reviewer": True,
+                        "id": TEST_USER_ID,
+                        "roles": {
+                            "Contributor": False,
+                            "Editor": False,
+                            "Reader": True,
+                            "Reviewer": True,
                         },
-                        u"type": u"user",
+                        "type": "user",
                     }
                 ]
             },
@@ -479,7 +479,7 @@ class TestFolderCreate(unittest.TestCase):
             sorted_roles(pas.getLocalRolesForDisplay(self.portal)),
             [
                 ["admin", ["Owner"], "user", "admin"],
-                ["test-user", [u"Reader", u"Reviewer"], "user", u"test_user_1_"],
+                ["test-user", ["Reader", "Reviewer"], "user", "test_user_1_"],
             ],
         )
 
@@ -596,7 +596,7 @@ class TestFolderCreate(unittest.TestCase):
         self.assertEqual(response.status_code, 501)
         response = response.json()
         self.assertIn("error", response)
-        self.assertEqual(u"No serializer available.", response["error"]["message"])
+        self.assertEqual("No serializer available.", response["error"]["message"])
 
         # we need to re-register the adapter here for following tests
         gsm.registerAdapter(SerializeLocalRolesToJson, name="local_roles")
