@@ -1,5 +1,7 @@
 from datetime import date
 from DateTime import DateTime
+from pkg_resources import get_distribution
+from pkg_resources import parse_version
 from plone import api
 from plone.app.discussion.interfaces import IDiscussionSettings
 from plone.app.layout.navigation.interfaces import INavigationRoot
@@ -21,6 +23,11 @@ import transaction
 import unittest
 
 
+HAS_PLONE_6 = parse_version(
+    get_distribution("Products.CMFPlone").version
+) >= parse_version("6.0.0a1")
+
+
 class TestSearchFunctional(unittest.TestCase):
 
     layer = PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
@@ -341,6 +348,33 @@ class TestSearchFunctional(unittest.TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(len(response.json()["items"]), 1)
 
+    def test_search_orphan_brain(self):
+
+        # prevent unindex when deleting self.doc
+        old__unindexObject = self.doc.__class__.unindexObject
+        self.doc.__class__.unindexObject = lambda *args: None
+        self.doc.aq_parent.manage_delObjects([self.doc.getId()])
+        self.doc.__class__.unindexObject = old__unindexObject
+        # doc deleted but still in portal_catalog
+        doc_uid = self.doc.UID()
+        self.assertFalse(self.doc in self.doc.aq_parent)
+        self.assertTrue(self.portal.portal_catalog(UID=doc_uid))
+        transaction.commit()
+
+        # query with fullobjects
+        query = {"portal_type": "DXTestDocument", "fullobjects": True, "UID": doc_uid}
+        response = self.api_session.get("/@search", params=query)
+        self.assertEqual(response.status_code, 200, response.content)
+        results = response.json()
+        self.assertEqual(len(results["items"]), 0)
+
+        # query without fullobjects
+        query = {"portal_type": "DXTestDocument", "UID": doc_uid}
+        response = self.api_session.get("/@search", params=query)
+        self.assertEqual(response.status_code, 200, response.content)
+        results = response.json()
+        self.assertEqual(len(results["items"]), 1)
+
     # ZCTextIndex
 
     def test_fulltext_search(self):
@@ -593,7 +627,12 @@ class TestSearchFunctional(unittest.TestCase):
     def test_respect_access_inactive_permission(self):
         # admin can see everything
         response = self.api_session.get("/@search", params={}).json()
-        self.assertEqual(response["items_total"], 6)
+        if HAS_PLONE_6:
+            # Since Plone 6 the Plone site is indexed ...
+            self.assertEqual(response["items_total"], 7)
+        else:
+            # ... before it was not
+            self.assertEqual(response["items_total"], 6)
         response = self.api_session.get(
             "/@search", params={"Title": "Lorem Ipsum"}
         ).json()
@@ -603,7 +642,12 @@ class TestSearchFunctional(unittest.TestCase):
         self.api_session.auth = ("editoruser", "secret")
 
         response = self.api_session.get("/@search", params={}).json()
-        self.assertEqual(response["items_total"], 3)
+        if HAS_PLONE_6:
+            # Since Plone 6 the Plone site is indexed ...
+            self.assertEqual(response["items_total"], 4)
+        else:
+            # ... before it was not
+            self.assertEqual(response["items_total"], 3)
         response = self.api_session.get(
             "/@search", params={"Title": "Lorem Ipsum"}
         ).json()
@@ -617,7 +661,12 @@ class TestSearchFunctional(unittest.TestCase):
 
         #  portal-enabled Editor can see expired contents
         response = self.api_session.get("/@search", params={}).json()
-        self.assertEqual(response["items_total"], 6)
+        if HAS_PLONE_6:
+            # Since Plone 6 the Plone site is indexed ...
+            self.assertEqual(response["items_total"], 7)
+        else:
+            # ... before it was not
+            self.assertEqual(response["items_total"], 6)
         response = self.api_session.get(
             "/@search", params={"Title": "Lorem Ipsum"}
         ).json()
@@ -626,7 +675,12 @@ class TestSearchFunctional(unittest.TestCase):
         # local-enabled Editor can only access expired contents inside folder
         self.api_session.auth = ("localeditor", "secret")
         response = self.api_session.get("/@search", params={}).json()
-        self.assertEqual(response["items_total"], 1)
+        if HAS_PLONE_6:
+            # Since Plone 6 the Plone site is indexed ...
+            self.assertEqual(response["items_total"], 2)
+        else:
+            # ... before it was not
+            self.assertEqual(response["items_total"], 1)
         response = self.api_session.get(
             "/@search", params={"path": "/plone/folder"}
         ).json()
@@ -748,15 +802,17 @@ class TestSearchFunctional(unittest.TestCase):
         response = self.api_session.get(
             vhm_url, params={"use_site_search_settings": 1, "path": "/"}
         ).json()
-        titles = [
-            "Some Folder",
-            "Lorem Ipsum",
-            "Other Document",
-            "Another Folder",
-            "Document in second folder",
-            "Doc outside folder",
-        ]
-        self.assertEqual([item["title"] for item in response["items"]], titles)
+        titles = sorted(
+            [
+                "Another Folder",
+                "Doc outside folder",
+                "Document in second folder",
+                "Lorem Ipsum",
+                "Other Document",
+                "Some Folder",
+            ]
+        )
+        self.assertEqual(sorted([item["title"] for item in response["items"]]), titles)
 
         noLongerProvides(self.folder, INavigationRoot)
         transaction.commit()
