@@ -8,7 +8,7 @@ from plone.restapi.services.contextnavigation.get import ContextNavigation
 from plone.restapi.testing import PLONE_RESTAPI_DX_FUNCTIONAL_TESTING
 from plone.restapi.testing import RelativeSession
 from Products.CMFPlone.tests import dummy
-from six.moves.urllib.parse import urlencode
+from urllib.parse import urlencode
 from zope.component import getUtility
 from zope.interface import directlyProvides
 from zope.interface import noLongerProvides
@@ -291,7 +291,7 @@ class TestServicesContextNavigation(unittest.TestCase):
         }
         qs = urlencode(q)
 
-        response = self.api_session.get("/folder2/@contextnavigation?{}".format(qs))
+        response = self.api_session.get(f"/folder2/@contextnavigation?{qs}")
         self.assertEqual(response.status_code, 200)
         res = response.json()
         base = self.portal.absolute_url()
@@ -561,7 +561,7 @@ class TestServicesContextNavigation(unittest.TestCase):
             self.portal.folder2.folder21,
             opts(
                 topLevel=1,
-                root_path=u"/folder2"
+                root_path="/folder2"
                 # self.portal.folder2.UID()
             ),
         )
@@ -584,11 +584,11 @@ class TestServicesContextNavigation(unittest.TestCase):
 
         view1 = self.renderer(
             self.portal.abc,
-            opts(topLevel=0, root_path=u"/abc"),
+            opts(topLevel=0, root_path="/abc"),
         )
         view2 = self.renderer(
             self.portal.abc,
-            opts(topLevel=0, root_path=u"/abcde"),
+            opts(topLevel=0, root_path="/abcde"),
         )
 
         tree1 = view1.getNavTree()
@@ -598,12 +598,12 @@ class TestServicesContextNavigation(unittest.TestCase):
 
         view1 = self.renderer(
             self.portal.abcde,
-            opts(topLevel=0, root_path=u"/abc"),
+            opts(topLevel=0, root_path="/abc"),
         )
 
         view2 = self.renderer(
             self.portal.abcde,
-            opts(topLevel=0, root_path=u"/abcde"),
+            opts(topLevel=0, root_path="/abcde"),
         )
 
         tree1 = view1.getNavTree()
@@ -697,7 +697,7 @@ class TestServicesContextNavigation(unittest.TestCase):
             self.portal.folder2.folder21,
             opts(
                 topLevel=1,
-                root_path=u"/folder2",
+                root_path="/folder2",
             ),
         )
         tree = view.getNavTree()
@@ -707,7 +707,7 @@ class TestServicesContextNavigation(unittest.TestCase):
         base = self.portal.absolute_url()
         view = self.renderer(
             self.portal.folder2.file21,
-            opts(root_path=u"", topLevel=0),
+            opts(root_path="", topLevel=0),
         )
         tree = view.getNavTree()
         self.assertTrue(tree)
@@ -717,7 +717,7 @@ class TestServicesContextNavigation(unittest.TestCase):
         base = self.portal.absolute_url()
         view = self.renderer(
             self.portal.folder2.file21,
-            opts(root_path=u"/folder2", topLevel=0),
+            opts(root_path="/folder2", topLevel=0),
         )
         tree = view.getNavTree()
         self.assertTrue(tree)
@@ -726,7 +726,7 @@ class TestServicesContextNavigation(unittest.TestCase):
     def testRootDoesNotExist(self):
         view = self.renderer(
             self.portal.folder2.file21,
-            opts(root_path=u"DOESNT_EXIST", topLevel=0),
+            opts(root_path="DOESNT_EXIST", topLevel=0),
         )
         tree = view.getNavTree()
         self.assertTrue(tree)
@@ -734,13 +734,8 @@ class TestServicesContextNavigation(unittest.TestCase):
 
     def testAboveRoot(self):
         base = self.portal.absolute_url()
-        try:
-            from Products.CMFPlone.interfaces import INavigationSchema  # noqa
-        except ImportError:
-            return  # skip test in Plone 4
-
         registry = getUtility(IRegistry)
-        registry["plone.root"] = u"/folder2"
+        registry["plone.root"] = "/folder2"
         view = self.renderer(self.portal, opts(topLevel=0))
         tree = view.getNavTree()
         self.assertTrue(tree)
@@ -750,7 +745,7 @@ class TestServicesContextNavigation(unittest.TestCase):
         base = self.portal.absolute_url()
         view = self.renderer(
             self.portal.folder1,
-            opts(root_path=u"/folder2", topLevel=0),
+            opts(root_path="/folder2", topLevel=0),
         )
         tree = view.getNavTree()
         self.assertTrue(tree)
@@ -810,11 +805,7 @@ class TestServicesContextNavigation(unittest.TestCase):
 
     def testStateFiltering(self):
         # Test Navtree workflow state filtering
-
-        try:
-            from Products.CMFPlone.interfaces import INavigationSchema  # noqa
-        except ImportError:
-            return  # skip test in Plone 4
+        from Products.CMFPlone.interfaces import INavigationSchema  # noqa
 
         setRoles(self.portal, TEST_USER_ID, ["Manager"])
         registry = getUtility(IRegistry)
@@ -841,14 +832,9 @@ class TestServicesContextNavigation(unittest.TestCase):
         self.assertEqual(len(tree["items"]), 2)
 
     def testPrunedRootNode(self):
-        try:
-            from Products.CMFPlone.interfaces import INavigationSchema  # noqa
-        except ImportError:
-            return  # skip test in Plone 4
-
         # This test has been changed to conform to reality
         registry = self.portal.portal_registry
-        registry["plone.parent_types_not_to_query"] = [u"Folder"]
+        registry["plone.parent_types_not_to_query"] = ["Folder"]
 
         view = self.renderer(self.portal.folder1, opts(topLevel=0))
         tree = view.getNavTree()
@@ -856,13 +842,8 @@ class TestServicesContextNavigation(unittest.TestCase):
         self.assertEqual(len(tree["items"][4]["items"]), 0)
 
     def testPrunedRootNodeShowsAllParents(self):
-        try:
-            from Products.CMFPlone.interfaces import INavigationSchema  # noqa
-        except ImportError:
-            return  # skip test in Plone 4
-
         registry = self.portal.portal_registry
-        registry["plone.parent_types_not_to_query"] = [u"Folder"]
+        registry["plone.parent_types_not_to_query"] = ["Folder"]
 
         view = self.renderer(self.portal.folder1.doc11, opts(topLevel=1))
         tree = view.getNavTree()
@@ -938,7 +919,7 @@ class TestServicesContextNavigation(unittest.TestCase):
         # make a navigation portlet with navigation root set
         view = self.renderer(
             self.portal.folder1.folder1_1,
-            opts(bottomLevel=0, topLevel=0, root_path=u"/folder1/folder1_1"),
+            opts(bottomLevel=0, topLevel=0, root_path="/folder1/folder1_1"),
         )
         tree = view(expand=True)["contextnavigation"]
 
@@ -959,7 +940,7 @@ class TestServicesContextNavigation(unittest.TestCase):
     def testServiceId(self):
         view = self.renderer(
             self.portal.folder2.file21,
-            opts(root_path=u"", topLevel=0),
+            opts(root_path="", topLevel=0),
         )
         portlet = view(expand=True)
 
