@@ -22,9 +22,20 @@ TEST_TERM_3 = SimpleTerm(44, token="token3")
 TEST_TERM_4 = UtilityTerm(45, "token4")
 TEST_TERM_5 = SimpleTerm(46, token="token5", title="Tötle 5")
 TEST_TERM_6 = SimpleTerm(47, token="token6", title="Tötle 6")
+TEST_TERM_7 = SimpleTerm(
+    48, token="token7", title="This is a title for the seventh term"
+)
 
 TEST_VOCABULARY = SimpleVocabulary(
-    [TEST_TERM_1, TEST_TERM_2, TEST_TERM_3, TEST_TERM_4, TEST_TERM_5, TEST_TERM_6]
+    [
+        TEST_TERM_1,
+        TEST_TERM_2,
+        TEST_TERM_3,
+        TEST_TERM_4,
+        TEST_TERM_5,
+        TEST_TERM_6,
+        TEST_TERM_7,
+    ]
 )
 
 
@@ -32,6 +43,15 @@ def test_vocabulary_factory(context):
     return TEST_VOCABULARY
 
 
+TEST_BIG_VOCABULARY = SimpleVocabulary(
+    [SimpleTerm(a, token=f"token{a}", title=f"Title {a}") for a in range(100)]
+)
+
+
+def test_big_vocabulary_factory(context):
+    return TEST_BIG_VOCABULARY
+
+
 def test_context_vocabulary_factory(context):
     return SimpleVocabulary(
         [
@@ -81,8 +101,12 @@ class TestVocabularyEndpoint(unittest.TestCase):
                     {"title": "token4", "token": "token4"},
                     {"title": "T\xf6tle 5", "token": "token5"},
                     {"title": "T\xf6tle 6", "token": "token6"},
+                    {
+                        "title": "This is a title for the seventh term",
+                        "token": "token7",
+                    },
                 ],
-                "items_total": 6,
+                "items_total": 7,
             },
         )
 
@@ -104,30 +128,40 @@ class TestVocabularyEndpoint(unittest.TestCase):
                     "first": self.portal_url
                     + "/@vocabularies/plone.restapi.tests.test_vocabulary?b_start=0&b_size=1",  # noqa
                     "last": self.portal_url
-                    + "/@vocabularies/plone.restapi.tests.test_vocabulary?b_start=5&b_size=1",  # noqa
+                    + "/@vocabularies/plone.restapi.tests.test_vocabulary?b_start=6&b_size=1",  # noqa
                     "next": self.portal_url
                     + "/@vocabularies/plone.restapi.tests.test_vocabulary?b_start=1&b_size=1",  # noqa
                 },
                 "items": [{"title": "Title 1", "token": "token1"}],
-                "items_total": 6,
+                "items_total": 7,
             },
         )
 
     def test_get_vocabulary_filtered_by_title(self):
         response = self.api_session.get(
-            "/@vocabularies/plone.restapi.tests.test_vocabulary?title=2"
+            "/@vocabularies/plone.restapi.tests.test_vocabulary?title=This"
         )
 
         self.assertEqual(200, response.status_code)
         response = response.json()
         self.assertEqual(
-            response,
-            {
-                "@id": self.portal_url
-                + "/@vocabularies/plone.restapi.tests.test_vocabulary?title=2",  # noqa
-                "items": [{"title": "Title 2", "token": "token2"}],
-                "items_total": 1,
-            },
+            response["items"][0],
+            {"title": "This is a title for the seventh term", "token": "token7"},
+        )
+        self.assertEqual(
+            response["items_total"],
+            1,
+        )
+
+        response = self.api_session.get(
+            "/@vocabularies/plone.restapi.tests.test_vocabulary?title=is+a+title"
+        )
+
+        self.assertEqual(200, response.status_code)
+        response = response.json()
+        self.assertEqual(
+            response["items"][0],
+            {"title": "This is a title for the seventh term", "token": "token7"},
         )
 
     def test_get_vocabulary_filtered_by_non_ascii_title(self):
@@ -150,6 +184,26 @@ class TestVocabularyEndpoint(unittest.TestCase):
             },
         )
 
+    def test_get_vocabulary_filtered_by_non_ascii_title_as_plain_utf(self):
+        response = self.api_session.get(
+            "/@vocabularies/plone.restapi.tests.test_vocabulary?title=tötle"
+        )
+
+        self.assertEqual(200, response.status_code)
+        response = response.json()
+        self.assertEqual(
+            response,
+            {
+                "@id": self.portal_url
+                + "/@vocabularies/plone.restapi.tests.test_vocabulary?title=t%C3%B6tle",  # noqa
+                "items": [
+                    {"title": "Tötle 5", "token": "token5"},
+                    {"title": "Tötle 6", "token": "token6"},
+                ],
+                "items_total": 2,
+            },
+        )
+
     def test_get_vocabulary_filtered_by_token(self):
         response = self.api_session.get(
             "/@vocabularies/plone.restapi.tests.test_vocabulary?token=token1"
@@ -286,6 +340,20 @@ class TestVocabularyEndpoint(unittest.TestCase):
             },
         )
 
+    def test_big_vocabulary_not_batched(self):
+        provideUtility(
+            test_big_vocabulary_factory,
+            provides=IVocabularyFactory,
+            name="plone.restapi.tests.test_big_vocabulary",
+        )
+        response = self.api_session.get(
+            "/@vocabularies/plone.restapi.tests.test_big_vocabulary?b_size=-1"
+        )
+
+        self.assertEqual(200, response.status_code)
+        response = response.json()
+        self.assertEqual(len(response["items"]), 100)
+
     def tearDown(self):
         self.api_session.close()
         gsm = getGlobalSiteManager()
